# -*- coding: utf-8 -*-

from django.conf import settings
from django.contrib import admin
from django.utils.translation import gettext_lazy as _
from thx.filters.admin import AdvancedSearchModelAdmin
from thx.core.admin import UserAdminMixin

from . import models


class AddressScopeAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('name',)
    advanced_search_fields = ()
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': (
                ('name', 'slug',),
                ('is_invoice_address', 'is_shipping_address',),
            )
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = (
        'id', 'status', 'name',
        'is_invoice_address', 'is_shipping_address',
        'ordering'
    )
    list_display_links = ('name',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')


class AddressAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ()
    advanced_search_fields = ()
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': (
                'address_scopes', 'address_type', 'name', 'number', 'crossed', 'scale',
                'floor', 'zip_code', 'locality', 'province', 'country', 'post_office',
                'administrative_area'
            )
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = (
        'id', 'status',
        'address_scopes', 'address_type', 'name', 'number', 'crossed', 'scale', 'floor',
        'zip_code', 'locality', 'province', 'country', 'post_office', 'administrative_area',
        'ordering'
    )
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')


class AddressCoordinateAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ()
    advanced_search_fields = ()
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': ('lat', 'lng', 'google_map')
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('lat', 'lng',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')

    class Media:
        js = (
            "https://maps.googleapis.com/maps/api/js?key={}".format(
                settings.ADDRESS_GOOGLE_GEOCODING_KEY
            ),
            "address/js/address_coordinates.js",
        )


admin.site.register(models.AddressScope, AddressScopeAdmin)
# admin.site.register(models.Address, AddressAdmin)
# admin.site.register(models.AddressCoordinate, AddressCoordinateAdmin)
