# -*- coding: utf-8 -*-

from rest_framework import serializers
from thx.api.serializers import (
    ThuxCreateSerializerMixin, ThuxDisableSerializerMixin, ThuxEnableSerializerMixin, ThuxListSerializerMixin,
    ThuxPartialUpdateSerializerMixin, ThuxRetrieveSerializerMixin, ThuxUpdateSerializerMixin,
)
from thx.role.core.serializers import ThuxRoleSerializerMixin

from ... import models


# ADDRESS SCOPE
class AddressScopeSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_address_address_scope'
        model = models.AddressScope
        fields = '__all__'


class AddressScopeListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_address_address_scope_list'
        model = models.AddressScope
        fields = '__all__'


class AddressScopeRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_address_address_scope_retrieve'
        model = models.AddressScope
        fields = '__all__'


class AddressScopeCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_address_address_scope_create'
        model = models.AddressScope
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = AddressScopeRetrieveSerializer


class AddressScopeUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_address_address_scope_update'
        model = models.AddressScope
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = AddressScopeRetrieveSerializer


class AddressScopePartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_address_address_scope_partial_update'
        model = models.AddressScope
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = AddressScopeRetrieveSerializer


class AddressScopeEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_address_address_scope_enable'
        model = models.AddressScope
        fields = ()
        response_serializer = AddressScopeRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class AddressScopeDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_address_address_scope_disable'
        model = models.AddressScope
        fields = ()
        response_serializer = AddressScopeRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class AddressScopeLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_address_address_scope_light'
        model = models.AddressScope
        fields = ('id', 'status', 'status_display',)


# ADDRESS
class AddressSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_address_address'
        model = models.Address
        fields = '__all__'


class AddressListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_address_address_list'
        model = models.Address
        fields = '__all__'


class AddressRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_address_address_retrieve'
        model = models.Address
        fields = '__all__'


class AddressCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_address_address_create'
        model = models.Address
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = AddressRetrieveSerializer


class AddressUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_address_address_update'
        model = models.Address
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = AddressRetrieveSerializer


class AddressPartialUpdateSerializer(ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_address_address_partial_update'
        model = models.Address
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = AddressRetrieveSerializer


class AddressEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_address_address_enable'
        model = models.Address
        fields = ()
        response_serializer = AddressRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class AddressDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_address_address_disable'
        model = models.Address
        fields = ()
        response_serializer = AddressRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class AddressLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_address_address_light'
        model = models.Address
        fields = ('id', 'status', 'status_display',)


# ADDRESS COORDINATE
class AddressCoordinateSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_address_address_coordinate'
        model = models.AddressCoordinate
        fields = '__all__'


class AddressCoordinateListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_address_address_coordinate_list'
        model = models.AddressCoordinate
        fields = '__all__'


class AddressCoordinateRetrieveSerializer(
    ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_address_address_coordinate_retrieve'
        model = models.AddressCoordinate
        fields = '__all__'


class AddressCoordinateCreateSerializer(
    ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_address_address_coordinate_create'
        model = models.AddressCoordinate
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = AddressCoordinateRetrieveSerializer


class AddressCoordinateUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_address_address_coordinate_update'
        model = models.AddressCoordinate
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = AddressCoordinateRetrieveSerializer


class AddressCoordinatePartialUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_address_address_coordinate_partial_update'
        model = models.AddressCoordinate
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = AddressCoordinateRetrieveSerializer


class AddressCoordinateEnableSerializer(
    ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_address_address_coordinate_enable'
        model = models.AddressCoordinate
        fields = ()
        response_serializer = AddressCoordinateRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class AddressCoordinateDisableSerializer(
    ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_address_address_coordinate_disable'
        model = models.AddressCoordinate
        fields = ()
        response_serializer = AddressCoordinateRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class AddressCoordinateLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_address_address_coordinate_light'
        model = models.AddressCoordinate
        fields = ('id', 'status', 'status_display',)
