# -*- coding: utf-8 -*-

from django.db import models


class NearbyManager(models.Manager):
    def nearby(self, lat, lng, proximity):
        """
        Return all object which distance to specified coordinates
        is less than proximity given in kilometers
        """
        # Great circle distance formula
        gcd = """
            6371 * acos(
                cos(radians(%s)) * cos(radians(lat))
                * cos(radians(lng) - radians(%s)) +
                sin(radians(%s)) * sin(radians(lat))
            )
        """
        gcd_lt = "{} < %s".format(gcd)
        return self.get_queryset().exclude(
            lat=None
        ).exclude(
            lng=None
        ).extra(
            select={'distance': gcd},
            select_params=[lat, lng, lat],
            where=[gcd_lt],
            params=[lat, lng, lat, proximity],
            order_by=['distance']
        )
