# -*- coding: utf-8 -*-

import math
import time

import requests
from django.conf import settings


def get_distance(lat1, lng1, lat2, lng2, radius=6371):
    """
    Uses the Haversine formula, resulting in an error of 0.5%
    By default, returns distance in km
    """
    lng1, lat1, lng2, lat2 = map(math.radians, [lng1, lat1, lng2, lat2])

    delta_lat = lng2 - lng1
    delta_lng = lat2 - lat1
    a = math.sin(delta_lat / 2) ** 2 + math.cos(lat1) * math.cos(lat2) * math.sin(delta_lng / 2) ** 2
    c = 2 * math.asin(math.sqrt(a))
    return c * radius


def get_google_geocoding(address):
    attempts = 0
    coordinates = dict(lat=None, lng=None)
    while attempts <= 3:
        req = requests.get(
            settings.ADDRESS_GOOGLE_GEOCODING_ENDPOINT,
            params={
                'key': settings.ADDRESS_GOOGLE_GEOCODING_KEY,
                'address': address,
            }
        )
        resp_json = req.json()
        attempts += 1
        if 'status' in resp_json and resp_json['status'] == "OVER_QUERY_LIMIT":
            time.sleep(2)
            continue
        elif 'results' in resp_json and resp_json['results'] and len(resp_json['results']):
            google_coordinates = resp_json['results'][0]['geometry']['location']
            coordinates['lat'], coordinates['lng'] = google_coordinates['lat'], google_coordinates['lng']
            break
    return coordinates
